@@ -46,6 +46,7 @@ from .type_defs import (
     DescribeServerResponseTypeDef,
     DescribeUserResponseTypeDef,
     DescribeWorkflowResponseTypeDef,
+    EmptyResponseMetadataTypeDef,
     EndpointDetailsTypeDef,
     HomeDirectoryMapEntryTypeDef,
     IdentityProviderDetailsTypeDef,
@@ -124,6 +125,14 @@ class TransferClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer/client/#can_paginate)
         """
 
+    def close(self) -> None:
+        """
+        Closes underlying endpoint connections.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/transfer.html#Transfer.Client.close)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer/client/#close)
+        """
+
     def create_access(
         self,
         *,
@@ -210,7 +219,7 @@ class TransferClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer/client/#create_workflow)
         """
 
-    def delete_access(self, *, ServerId: str, ExternalId: str) -> None:
+    def delete_access(self, *, ServerId: str, ExternalId: str) -> EmptyResponseMetadataTypeDef:
         """
         Allows you to delete the access specified in the `ServerID` and `ExternalID`
         parameters.
@@ -219,7 +228,7 @@ class TransferClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer/client/#delete_access)
         """
 
-    def delete_server(self, *, ServerId: str) -> None:
+    def delete_server(self, *, ServerId: str) -> EmptyResponseMetadataTypeDef:
         """
         Deletes the file transfer protocol-enabled server that you specify.
 
@@ -227,7 +236,9 @@ class TransferClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer/client/#delete_server)
         """
 
-    def delete_ssh_public_key(self, *, ServerId: str, SshPublicKeyId: str, UserName: str) -> None:
+    def delete_ssh_public_key(
+        self, *, ServerId: str, SshPublicKeyId: str, UserName: str
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Deletes a user's Secure Shell (SSH) public key.
 
@@ -235,7 +246,7 @@ class TransferClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer/client/#delete_ssh_public_key)
         """
 
-    def delete_user(self, *, ServerId: str, UserName: str) -> None:
+    def delete_user(self, *, ServerId: str, UserName: str) -> EmptyResponseMetadataTypeDef:
         """
         Deletes the user belonging to a file transfer protocol-enabled server you
         specify.
@@ -244,7 +255,7 @@ class TransferClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer/client/#delete_user)
         """
 
-    def delete_workflow(self, *, WorkflowId: str) -> None:
+    def delete_workflow(self, *, WorkflowId: str) -> EmptyResponseMetadataTypeDef:
         """
         Deletes the specified workflow.
 
@@ -419,7 +430,7 @@ class TransferClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer/client/#send_workflow_step_state)
         """
 
-    def start_server(self, *, ServerId: str) -> None:
+    def start_server(self, *, ServerId: str) -> EmptyResponseMetadataTypeDef:
         """
         Changes the state of a file transfer protocol-enabled server from `OFFLINE` to
         `ONLINE`.
@@ -428,7 +439,7 @@ class TransferClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer/client/#start_server)
         """
 
-    def stop_server(self, *, ServerId: str) -> None:
+    def stop_server(self, *, ServerId: str) -> EmptyResponseMetadataTypeDef:
         """
         Changes the state of a file transfer protocol-enabled server from `ONLINE` to
         `OFFLINE`.
@@ -437,7 +448,7 @@ class TransferClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer/client/#stop_server)
         """
 
-    def tag_resource(self, *, Arn: str, Tags: Sequence[TagTypeDef]) -> None:
+    def tag_resource(self, *, Arn: str, Tags: Sequence[TagTypeDef]) -> EmptyResponseMetadataTypeDef:
         """
         Attaches a key-value pair to a resource, as identified by its Amazon Resource
         Name (ARN).
@@ -464,7 +475,7 @@ class TransferClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_transfer/client/#test_identity_provider)
         """
 
-    def untag_resource(self, *, Arn: str, TagKeys: Sequence[str]) -> None:
+    def untag_resource(self, *, Arn: str, TagKeys: Sequence[str]) -> EmptyResponseMetadataTypeDef:
         """
         Detaches a key-value pair from a resource, as identified by its Amazon Resource
         Name (ARN).
