@@ -95,6 +95,7 @@ __all__ = (
     "CreateServerResponseTypeDef",
     "CreateUserResponseTypeDef",
     "CreateWorkflowResponseTypeDef",
+    "EmptyResponseMetadataTypeDef",
     "ImportSshPublicKeyResponseTypeDef",
     "ListSecurityPoliciesResponseTypeDef",
     "TestIdentityProviderResponseTypeDef",
@@ -842,6 +843,13 @@ CreateWorkflowResponseTypeDef = TypedDict(
     },
 )
 
+EmptyResponseMetadataTypeDef = TypedDict(
+    "EmptyResponseMetadataTypeDef",
+    {
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 ImportSshPublicKeyResponseTypeDef = TypedDict(
     "ImportSshPublicKeyResponseTypeDef",
     {
